heros-boss 0.6.10 documentation

Skip to content
Back to top
View this page

# BOSS: Configuration driven object/HERO starter

BOSS is a service that instantiates python objects as HEROs based on a JSON configuration. The configuration can be read from a file, a URL (e.g. from a CouchDB) or from an environment variable. Basically, BOSS allows you to quickly mask your arbitrary python object as a HERO and to run it.

The configuration sources (for example an URL specified by the `-u` command line argument) can be reloaded in-situ without disturbing the running HEROs by using `boss.boss.BOSS.refresh_hero_sources()`. Sources can also be added and removed by using `boss.boss.BOSS.add_hero_source()` or by manipulating the `boss.boss.BOSS.sources` list directly.

- Getting Started
  - Possible Configuration Sources
  - Installing/Deploying BOSS
  - Additional Dependencies in Docker
  - Accessing Devices inside a Container
- CouchDB for BOSS
  - Using Views
- JSON Configuration Format
  - Single HERO Config
  - Special Arguments
  - Extra Decorators
  - Datasource Keys
  - External Library Integrations
  - Multiple HERO Configs
- API Reference
  - boss

# Indices and tables

- Index

- Module Index

- Search Page